==> tine20-allinone_2020.03.4.tar.bz2: ActiveSync/js/ActiveSync-lang-de-debug.js <==
/************************** namespace for static data **************************/ 
Tine = window.Tine || {};
Tine.__translationData = Tine.__translationData || {};
Tine.__translationData.msgs = Tine.__translationData.msgs || {};
/********************** tine translations of ActiveSync **********************/ 
Tine.__translationData.msgs['./LC_MESSAGES/ActiveSync'] = ({
""
: "Project-Id-Version: Tine 2.0\nPOT-Creation-Date: 2008-05-17 22:12+0100\nPO-Revision-Date: 2020-04-06 10:49+0200\nLast-Translator: Paul Hartog <p.hartog@metaways.de>\nLanguage-Team: German (http://www.transifex.com/tine20/tine20/language/de/)\nLanguage: de\nMIME-Version: 1.0\nContent-Type: text/plain; charset=UTF-8\nContent-Transfer-Encoding: 8bit\nPlural-Forms: nplurals=2; plural=(n != 1);\nX-Poedit-SourceCharset: utf-8\nX-Generator: Poedit 2.3\n"

, "Default Address book"
: "Standardadressbuch"

, "The default address book to create new contacts in."
: "Das Standard-Adressbuch für neue Kontakte."

, "Default Calendar"
: "Standard-Kalender"

, "The default calendar to create new events in."
: "Der Standard-Kalender, in dem neue Termine angelegt werden."

, "Default Task List"
: "Standard-Aufgabenliste"

, "The default task list to create new tasks in."
: "Die Standard-Aufgabenliste, in der neue Aufgaben angelegt werden."

, "Sync Devices"
: "Sync Geräte"

, "Device ID"
: "Geräte ID"

, "Devicetype"
: "Gerätetyp"

, "Owner"
: "Eigentümer"

, "Policy"
: "Richtlinie"

, "ActiveSync Version"
: "ActiveSync Version"

, "User agent"
: "User Agent"

, "Model"
: "Modell"

, "IMEI"
: "IMEI"

, "Friendly Name"
: "Friendly Name"

, "OS"
: "OS"

, "OS Language"
: "OS Sprache"

, "Phonenumber"
: "Telefonnummer"

, "Sync Device, Sync Devices"
: [
  "Sync Gerät"
 ,"Sync Geräte"

]
, "Device, Devices"
: [
  "Gerät"
 ,"Geräte"

]
, "Devices"
: "Geräte"

, "Active Sync"
: "ActiveSync"

, "Select a Device"
: "Gerät auswählen"

, "No ActiveSync Device registered"
: "Kein ActiveSync Gerät verfügbar"

, "Set as {0} Filter"
: "Als {0} Filter setzen"

, "Resetted Sync Filter"
: "Sync Filter zurückgesetzt"

, "{0} filter for device \"{1}\" is now \"{2}\""
: "{0} Filter für das Gerät \"{1}\" ist jetzt \"{2}\""

, "resetted"
: "zurückgesetzt"

, "Set Sync Filter"
: "Setze Sync Filter"

, "ID"
: "ID"

, "Device Type"
: "Geräte Typ"

, "Operating System"
: "Betriebssystem"

, "Phone Number"
: "Handynummer"

, "Ping Lifetime"
: "Ping Laufzeit"

, "Ping Folder"
: "Ping Ordner"

, "Remote Wipe"
: "Gerät löschen"

, "Calendar Filter"
: "Kalender Filter"

, "Contacts Filter"
: "Kontakt Filter"

, "E-mail Filter"
: "E-Mail Filter"

, "Tasks Filter"
: "Aufgaben Filter"

, "Last Ping"
: "Letzter Ping"

, "Monitor Last Ping"
: "Letzten Ping überwachen"

, "Remote Device Reset"
: "Gerät zurücksetzen (Fernzugriff)"

, "Please Confirm"
: "Bitte bestätigen"

, "Do you really want to wipe the selected devices? All personal data will be removed and the device will be reset to factory settings!"
: "Möchten Sie die ausgewählten Geräte wirklich löschen? Alle persönlichen Daten werden entfernt und das Gerät auf die Werkseinstellungen zurückgesetzt!"

, "Quicksearch"
: "Schnellsuche"

, "Default Policy"
: "Standardrichtlinie"

, "Default Policy installed during setup"
: "Standardrichtlinie aus dem Setup Prozess"

, "Default policy for new devices"
: "Standardrichtlinie für neue Geräte"

, "Enter the id of the policy to apply to newly created devices."
: "Geben Sie die ID der Richtlinie für neue Geräte an."

, "User Agent Deny List"
: ""

, "Array of regular expressions of User-Agent strings"
: ""

, "Disable Access Log"
: "Zugriffe nicht protokolieren"

, "Disable ActiveSync Access Log creation."
: "Zugriffe per ActiveSync nicht im Zugriffslog speichern."

, "Filter timeslot for e-mails"
: "Filter Zeitpunkt für E-Mails"

, "For how long in the past the e-mails should be synchronized."
: "Maximales Alter für E-Mails die synchronisiert werden dürfen."

, "Filter timeslot for events"
: "Maximales Alter für Termine"

, "For how long in the past the events should be synchronized."
: "Maximales Alter für Termine die synchronisiert werden dürfen."

, "Manage ActiveSync devices"
: "ActiveSync Geräte verwalten"

, "See, edit and delete ActiveSync devices"
: "ActiveSync Geräte sehen, verwalten und löschen"

, "Reset ActiveSync devices"
: "ActiveSync Geräte zurücksetzen"

, "Remotely reset ActiveSync devices to factory state, deleting all data"
: "Zurücksetzen der ActiveSync-Geräte per Fernzugriff auf den Werkszustand (alle Daten werden gelöscht)"














, "Sync Device"
: "Sync Gerät"

, "Device"
: "Gerät"

}); 
/********************** translation loaded flag **********************/ 
Tine.__translationData.__isLoaded = true;

==> tine20-allinone_2021.12.1.tar.bz2: ActiveSync/js/ActiveSync-lang-de-debug.js <==
/************************** namespace for static data **************************/ 
Tine = window.Tine || {};
Tine.__translationData = Tine.__translationData || {};
Tine.__translationData.msgs = Tine.__translationData.msgs || {};
/********************** tine translations of ActiveSync **********************/ 
Tine.__translationData.msgs['./LC_MESSAGES/ActiveSync'] = ({
""
: "Project-Id-Version: Tine 2.0\nPOT-Creation-Date: 2008-05-17 22:12+0100\nPO-Revision-Date: 2020-04-06 10:49+0200\nLast-Translator: Paul Hartog <p.hartog@metaways.de>\nLanguage-Team: German (http://www.transifex.com/tine20/tine20/language/de/)\nLanguage: de\nMIME-Version: 1.0\nContent-Type: text/plain; charset=UTF-8\nContent-Transfer-Encoding: 8bit\nPlural-Forms: nplurals=2; plural=(n != 1);\nX-Poedit-SourceCharset: utf-8\nX-Generator: Poedit 2.3\n"

, "Active Sync"
: "ActiveSync"

, "Select a Device"
: "Gerät auswählen"

, "No ActiveSync Device registered"
: "Kein ActiveSync Gerät verfügbar"

, "Set as {0} Filter"
: "Als {0} Filter setzen"

, "Resetted Sync Filter"
: "Sync Filter zurückgesetzt"

, "{0} filter for device \"{1}\" is now \"{2}\""
: "{0} Filter für das Gerät \"{1}\" ist jetzt \"{2}\""

, "resetted"
: "zurückgesetzt"

, "Set Sync Filter"
: "Setze Sync Filter"

, "Sync Devices"
: "Sync Geräte"

, "ID"
: "ID"

, "Device ID"
: "Geräte ID"

, "Device Type"
: "Geräte Typ"

, "Owner"
: "Eigentümer"

, "Policy"
: "Richtlinie"

, "ActiveSync Version"
: "ActiveSync Version"

, "User agent"
: "User Agent"

, "Model"
: "Modell"

, "IMEI"
: "IMEI"

, "Friendly Name"
: "Friendly Name"

, "Operating System"
: "Betriebssystem"

, "OS Language"
: "OS Sprache"

, "Phone Number"
: "Handynummer"

, "Ping Lifetime"
: "Ping Laufzeit"

, "Ping Folder"
: "Ping Ordner"

, "Remote Wipe"
: "Gerät löschen"

, "Calendar Filter"
: "Kalender Filter"

, "Contacts Filter"
: "Kontakt Filter"

, "E-mail Filter"
: "E-Mail Filter"

, "Tasks Filter"
: "Aufgaben Filter"

, "Last Ping"
: "Letzter Ping"

, "Monitor Last Ping"
: "Letzten Ping überwachen"

, "Remote Device Reset"
: "Gerät zurücksetzen (Fernzugriff)"

, "Please Confirm"
: "Bitte bestätigen"

, "Do you really want to wipe the selected devices? All personal data will be removed and the device will be reset to factory settings!"
: "Möchten Sie die ausgewählten Geräte wirklich löschen? Alle persönlichen Daten werden entfernt und das Gerät auf die Werkseinstellungen zurückgesetzt!"

, "Quicksearch"
: "Schnellsuche"

, "Sync Device, Sync Devices"
: [
  "Sync Gerät"
 ,"Sync Geräte"

]
, "Device, Devices"
: [
  "Gerät"
 ,"Geräte"

]
, "Devices"
: "Geräte"

, "Devicetype"
: "Gerätetyp"

, "OS"
: "OS"

, "Phonenumber"
: "Telefonnummer"

, "Default Address book"
: "Standardadressbuch"

, "The default address book to create new contacts in."
: "Das Standard-Adressbuch für neue Kontakte."

, "Default Calendar"
: "Standard-Kalender"

, "The default calendar to create new events in."
: "Der Standard-Kalender, in dem neue Termine angelegt werden."

, "Default Task List"
: "Standard-Aufgabenliste"

, "The default task list to create new tasks in."
: "Die Standard-Aufgabenliste, in der neue Aufgaben angelegt werden."

, "Default policy for new devices"
: "Standardrichtlinie für neue Geräte"

, "Enter the id of the policy to apply to newly created devices."
: "Geben Sie die ID der Richtlinie für neue Geräte an."

, "Device Model Agent Deny List"
: ""

, "Array of regular expressions of Device-Model strings"
: ""

, "User Agent Deny List"
: ""

, "Array of regular expressions of User-Agent strings"
: ""

, "Disable Access Log"
: "Zugriffe nicht protokolieren"

, "Disable ActiveSync Access Log creation."
: "Zugriffe per ActiveSync nicht im Zugriffslog speichern."

, "Filter timeslot for e-mails"
: "Filter Zeitpunkt für E-Mails"

, "For how long in the past the e-mails should be synchronized."
: "Maximales Alter für E-Mails die synchronisiert werden dürfen."

, "Filter timeslot for events"
: "Maximales Alter für Termine"

, "For how long in the past the events should be synchronized."
: "Maximales Alter für Termine die synchronisiert werden dürfen."

, "%1$s ActiveSync failure"
: ""

, "Dear user,"
: ""

, "%1$s has noticed that the syncronization with your ActiveSync device is no longer active. Please trigger the syncronisation on your device."
: ""

, "Thank you."
: ""

, "Your %1$s Team"
: ""

, "Default Policy"
: "Standardrichtlinie"

, "Default Policy installed during setup"
: "Standardrichtlinie aus dem Setup Prozess"

, "Manage ActiveSync devices"
: "ActiveSync Geräte verwalten"

, "See, edit and delete ActiveSync devices"
: "ActiveSync Geräte sehen, verwalten und löschen"

, "Reset ActiveSync devices"
: "ActiveSync Geräte zurücksetzen"

, "Remotely reset ActiveSync devices to factory state, deleting all data"
: "Zurücksetzen der ActiveSync-Geräte per Fernzugriff auf den Werkszustand (alle Daten werden gelöscht)"














, "Sync Device"
: "Sync Gerät"

, "Device"
: "Gerät"

}); 
/********************** translation loaded flag **********************/ 
Tine.__translationData.__isLoaded = true;
